@@ -256,15 +256,14 @@ impl Command {
             results
                 .for_each(|(mut result, manifest, src, dest)| async move {
                     // verify file hashes if manifest entry exists
-                    if !self.force {
-                        if let Some(manifest) = manifest.as_ref() {
-                            if result.is_ok() {
-                                result = match tokio::fs::read(&src).await {
-                                    Ok(data) => manifest.verify(&data),
-                                    Err(e) => Err(Error::InvalidValue(format!(
-                                        "failed reading: {src}: {e}"
-                                    ))),
-                                }
+                    if !self.force
+                        && let Some(manifest) = manifest.as_ref()
+                        && result.is_ok()
+                    {
+                        result = match tokio::fs::read(&src).await {
+                            Ok(data) => manifest.verify(&data),
+                            Err(e) => {
+                                Err(Error::InvalidValue(format!("failed reading: {src}: {e}")))
                             }
                         }
                     }
