@@ -2,13 +2,17 @@ use std::process::ExitCode;
 
 use pkgcraft::config::Config;
 
+mod add;
 mod eapi;
 mod eclass;
 mod leaf;
 mod license;
+mod list;
 mod metadata;
 mod mirror;
+mod remove;
 mod revdeps;
+mod sync;
 
 #[derive(clap::Args)]
 pub(crate) struct Command {
@@ -23,33 +27,46 @@ impl Command {
 }
 
 #[derive(clap::Subcommand)]
+#[allow(clippy::large_enum_variant)]
 enum Subcommand {
+    /// Add repository to config
+    Add(add::Command),
     /// Output EAPI statistics
-    Eapi(Box<eapi::Command>),
+    Eapi(eapi::Command),
     /// Output eclass statistics
-    Eclass(Box<eclass::Command>),
+    Eclass(eclass::Command),
     /// Output leaf packages
-    Leaf(Box<leaf::Command>),
+    Leaf(leaf::Command),
     /// Output license statistics
-    License(Box<license::Command>),
+    License(license::Command),
+    /// List repositories
+    List(list::Command),
     /// Manipulate repo metadata
-    Metadata(Box<metadata::Command>),
+    Metadata(metadata::Command),
     /// Output mirror statistics
-    Mirror(Box<mirror::Command>),
+    Mirror(mirror::Command),
+    /// Remove repositories
+    Remove(remove::Command),
     /// Output revdeps cache
-    Revdeps(Box<revdeps::Command>),
+    Revdeps(revdeps::Command),
+    /// Sync repos
+    Sync(sync::Command),
 }
 
 impl Subcommand {
     fn run(&self, config: &mut Config) -> anyhow::Result<ExitCode> {
         match self {
+            Self::Add(cmd) => cmd.run(config),
             Self::Eapi(cmd) => cmd.run(config),
             Self::Eclass(cmd) => cmd.run(config),
             Self::Leaf(cmd) => cmd.run(config),
             Self::License(cmd) => cmd.run(config),
+            Self::List(cmd) => cmd.run(config),
             Self::Metadata(cmd) => cmd.run(config),
             Self::Mirror(cmd) => cmd.run(config),
+            Self::Remove(cmd) => cmd.run(config),
             Self::Revdeps(cmd) => cmd.run(config),
+            Self::Sync(cmd) => cmd.run(config),
         }
     }
 }
