@@ -1,7 +1,11 @@
+mod add;
 mod eapi;
 mod eclass;
 mod leaf;
 mod license;
+mod list;
 mod metadata;
 mod mirror;
+mod remove;
 mod revdeps;
+mod sync;
