@@ -12,6 +12,16 @@ fn nonexistent_repo() {
         .code(2);
 }
 
+#[test]
+fn portage_repos() {
+    cmd("pk repo remove --portage repo")
+        .assert()
+        .stdout("")
+        .stderr(contains("config error: can't alter portage repos"))
+        .failure()
+        .code(2);
+}
+
 #[test]
 fn remove() {
     let data = test_data();
